__author__ = "Lukas Leufen"
__date__ = '2019-11-14'


import argparse

from src.run_modules.experiment_setup import ExperimentSetup
from src.run_modules.partition_check import PartitionCheck
from src.run_modules.model_setup import ModelSetup
from src.run_modules.post_processing import PostProcessing
from src.run_modules.pre_processing import PreProcessing
from src.run_modules.run_environment import RunEnvironment
from src.run_modules.training import Training


def main(parser_args):

    with RunEnvironment():
        ExperimentSetup(parser_args, stations=['DEBW107', 'DEBY081', 'DEBW013', 'DEBW076', 'DEBW087', 'DEBW001'],
                        station_type='background', trainable=False, create_new_model=True, window_history_size=6,
                        create_new_bootstraps=False)
        PreProcessing()

        PartitionCheck()
        
        ModelSetup()

        Training()

        PostProcessing()

if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument('--experiment_date', metavar='--exp_date', type=str, default="testrun",
                        help="set experiment date as string")
    args = parser.parse_args()

    main(args)

